/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include<libintl.h>
#include "importexportdlg.h"
#include"mainwindow.h"
#include"globals.h"

IEDialog::IEDialog(BaseObjectType* cobject, 
                       const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
: Gtk::Window(cobject),
  m_refGlade(refGlade),
  wizardNotebook(0),
  importRadioButton(0),
  exportRadioButton(0),
  nextButton(0),
  nextButtonLabel(0),
  nextImage(0),
  backButton(0),
  importBrowseButton(0),
  exportBrowseButton(0),
  importFileNameEntry(0),
  exportFileNameEntry(0),
  importFileChooser(0),
  importFileChooserOKButton(0),
  exportFileChooser(0),
  exportFileChooserOKButton(0)
{
    refGlade->get_widget("WizardNotebook", wizardNotebook);
    refGlade->get_widget("ImportRadioButton", importRadioButton);
    refGlade->get_widget("ExportRadioButton", exportRadioButton);
    refGlade->get_widget("NextButton", nextButton);
    refGlade->get_widget("NextButtonLabel", nextButtonLabel);
    refGlade->get_widget("NextImage", nextImage);
    refGlade->get_widget("BackButton", backButton);
    refGlade->get_widget("ImportBrowseButton", importBrowseButton);
    refGlade->get_widget("ExportBrowseButton", exportBrowseButton);
    refGlade->get_widget("ImportFileNameEntry", importFileNameEntry);
    refGlade->get_widget("ExportFileNameEntry", exportFileNameEntry);

    Gtk::ComboBox* combo = 0;
    refGlade->get_widget("ImportFormatComboBox", combo);
    if(combo) {
        combo->set_active(0);
    }
    refGlade->get_widget("ExportFormatComboBox", combo);
    if(combo) {
        combo->set_active(0);
    }
    
    if(nextButton)
    {
      nextButton->signal_clicked().connect(sigc::mem_fun(*this, &IEDialog::on_next_click));
    }

    if(backButton)
    {
      backButton->signal_clicked().connect(sigc::mem_fun(*this, &IEDialog::on_back_click));
    }

    Gtk::Button* pButton = 0;
    refGlade->get_widget("CancelButton", pButton);
    if(pButton)
    {
      pButton->signal_clicked().connect(sigc::mem_fun(*this, &IEDialog::on_cancel_click));
    }

    pButton = 0;
    refGlade->get_widget("ImportBrowseButton", pButton);
    if(pButton)
    {
      pButton->signal_clicked().connect(sigc::mem_fun(*this, &IEDialog::on_browse_click));
    }
    pButton = 0;
    refGlade->get_widget("ExportBrowseButton", pButton);
    if(pButton)
    {
      pButton->signal_clicked().connect(sigc::mem_fun(*this, &IEDialog::on_browse_click));
    }    
}


IEDialog::~IEDialog()
{
    if(exportFileChooser) delete exportFileChooser;
    if(importFileChooser) delete importFileChooser;
}

void IEDialog::present(PCalMainWindow * main_window)
{
    pMainWindow = main_window;
    on_back_click();
    Gtk::Window::present();
}

void IEDialog::on_next_click()
{
    Glib::ustring fname = "";
    switch (wizardNotebook->get_current_page()) {
        case 0:
            nextButtonLabel->set_text(gettext("Finish"));
            nextImage->set(Gtk::Stock::OK, Gtk::ICON_SIZE_BUTTON);
            if(importRadioButton->get_active()) {
                wizardNotebook->set_current_page(1);
            } else
            if(exportRadioButton->get_active()) {
                wizardNotebook->set_current_page(2);
            }            
            backButton->set_sensitive(true);
            break;
        case 1:
            fname = importFileNameEntry->get_text();
            if(pMainWindow->engine->importFromFile(fname,0)) {
                pMainWindow->refreshCalendarView();
                hide();
            } else {
                Gtk::MessageDialog *idialog = new class Gtk::MessageDialog(
                    gettext("Can not import from file: \n")+
                    fname,
		            false,
                    Gtk::MESSAGE_ERROR,
                    Gtk::BUTTONS_OK,
                    true);
                idialog->set_transient_for(*this);
                idialog->run();
                delete idialog;                 
            }
            break;
        case 2:
            fname = exportFileNameEntry->get_text();
            if(pMainWindow->engine->exportToFile(fname,0)) {
                hide();
            } else {
                Gtk::MessageDialog *edialog = new class Gtk::MessageDialog(
                    gettext("Can not export to file: \n")+
                    fname,
		            false,
                    Gtk::MESSAGE_ERROR,
                    Gtk::BUTTONS_OK,
                    true);
                edialog->set_transient_for(*this);
                edialog->run();
                delete edialog;                 
            }
            break;
        default: ;
    }    
}

void IEDialog::on_back_click()
{
    // back always switching to the first page
    backButton->set_sensitive(false);
    wizardNotebook->set_current_page(0);
    nextButtonLabel->set_text(gettext("Next"));
    nextImage->set(Gtk::Stock::GO_FORWARD, Gtk::ICON_SIZE_BUTTON);
}

void IEDialog::on_cancel_click()
{
  	hide();
}

void IEDialog::on_browse_click()
{
    Gtk::FileChooserDialog* dialog = 0;
    Gtk::Entry* entry = 0;
    // is it import or export?
    switch (wizardNotebook->get_current_page()) {
        case 1:
            // this is import
            if(!importFileChooser) {
              Glib::RefPtr<Gnome::Glade::Xml> refXml;
              try {
                  refXml = 
                  Gnome::Glade::Xml::create(glade_interface_path,
                         "ImportFileChooserDialog");
              }
              catch(const Gnome::Glade::XmlError& ex)
              {
                std::cerr << ex.what() << std::endl;
                return;
              } 
              refXml->get_widget("ImportFileChooserDialog", importFileChooser);
              refXml->get_widget("dialog-action_area2", importFileChooserButtonBox);
              refXml->get_widget("OKButton", importFileChooserOKButton);
              
              importFileChooser->set_transient_for(*this);              
            }  
            if(Gtk::Dialog::alternative_button_order(get_screen())) {
                importFileChooserButtonBox->reorder_child(*importFileChooserOKButton, 0);
            } else {
                importFileChooserButtonBox->reorder_child(*importFileChooserOKButton, 1);
            }

            dialog = importFileChooser;
            entry = importFileNameEntry;
            break;
        case 2:
            // this is export          
            if(!exportFileChooser) {
              Glib::RefPtr<Gnome::Glade::Xml> refXml;
              try {
                  refXml = 
                  Gnome::Glade::Xml::create(glade_interface_path,
                         "ExportFileChooserDialog");
              }
              catch(const Gnome::Glade::XmlError& ex)
              {
                std::cerr << ex.what() << std::endl;
                return;
              } 
              refXml->get_widget("ExportFileChooserDialog", exportFileChooser);
              refXml->get_widget("hbuttonbox4", exportFileChooserButtonBox);
              refXml->get_widget("OKButton", exportFileChooserOKButton);              
              
              exportFileChooser->set_transient_for(*this);
            }
            if(Gtk::Dialog::alternative_button_order(get_screen())) {
                exportFileChooserButtonBox->reorder_child(*exportFileChooserOKButton, 0);
            } else {
                exportFileChooserButtonBox->reorder_child(*exportFileChooserOKButton, 1);
            }
            
            dialog = exportFileChooser;
            entry = exportFileNameEntry;
            break;
        default: ;
    }
    if(dialog && entry) {
        if(entry->get_text() != "") {
            dialog->set_filename(Glib::filename_from_utf8(entry->get_text()));        
        }
        //Handle the response:
        if(dialog->run() == Gtk::RESPONSE_OK) {          
          entry->set_text(Glib::filename_to_utf8(dialog->get_filename()));
        }
        dialog->hide();
    }
}
